summaryrefslogtreecommitdiff
path: root/win/prevview.h
diff options
context:
space:
mode:
Diffstat (limited to 'win/prevview.h')
-rw-r--r--win/prevview.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/win/prevview.h b/win/prevview.h
index 2114b00..7f61ad5 100644
--- a/win/prevview.h
+++ b/win/prevview.h
@@ -1,4 +1,4 @@
// PrevView.h: interface for the CPreviewViewEx class.
//
//////////////////////////////////////////////////////////////////////
@@ -14,13 +14,13 @@
class CCADView;
-class CPreviewViewEx : public CScrollView
+class CCADPreviewView : public CScrollView
{
- DECLARE_DYNCREATE(CPreviewViewEx)
+ DECLARE_DYNCREATE(CCADPreviewView)
// Constructors
public:
- CPreviewViewEx();
+ CCADPreviewView();
BOOL SetPrintView(CCADView* pPrintView);
// Attributes
@@ -52,7 +52,7 @@ protected:
// Implementation
public:
- virtual ~CPreviewViewEx();
+ virtual ~CCADPreviewView();
virtual void OnPrepareDC(CDC* pDC, CPrintInfo* pInfo = NULL);
#ifdef _DEBUG
void AssertValid() const;
@@ -63,7 +63,7 @@ public:
#endif
protected:
- //{{AFX_MSG(CPreviewViewEx)
+ //{{AFX_MSG(CCADPreviewView)
afx_msg void OnPreviewClose();
afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
afx_msg void OnSize(UINT nType, int cx, int cy);
@@ -1,4 +1,4 @@
-// PrevView.h: interface for the CPreviewViewEx class.
+// PrevView.h: interface for the CCADPreviewView class.
//
//////////////////////////////////////////////////////////////////////